@@ -21,6 +21,17 @@ def load_json(dest):
             return json.load(f)
     except:
         return None
+    
+def ticker_join(a,b):
+    return list(set(a) & set(b))
+
+def ticker_join(data, tickers): # FS에만 주로 효과가 있는듯..?
+    if type(data) == pd.DataFrame:
+        a = data.columns
+    elif type(data) == pd.Series:
+        a = data.index
+    tickers = list(set(a) & set(tickers))
+    return data[tickers]
 
 
 class QuickDB:
@@ -34,8 +45,24 @@ class QuickDB:
         else:
             self.yqtb = yqtb
             self.fsdata = fsdata
-        
+    
+    def getFSaccounts(self):
+        return list(self.fsdata['200003'].keys())
 
+    def getIDX(self):
+        return load_pkl(os.path.join(self.path, 'data/IDX.data'))
+    
+    def getBdays(self, stringify=False, inverted=False):
+        if stringify:
+            _ = self.getIDX().index.map(lambda x : x.strftime("%Y%m%d"))
+        else:
+            _ = self.getIDX().index
+        if inverted:
+            return {v:i for i, v in enumerate(_)}
+        else:
+            return _
+
+        
     def refresh(self): # daily update하면 refresh 해줘야함.
         self.yqtb = load_pkl(os.path.join(self.path, 'yq.table'))
         self.fsdata = load_pkl(os.path.join(self.path, 'fsdata.data'))
@@ -52,8 +79,24 @@ class QuickDB:
         else:
             return pd.Series(result)
 
-    def getTradables(self, date):
-        return self.getTS(88, date).where(lambda x : x == 0).dropna()
+    def getTradables(self, start, end=None):
+        """
+        date에 거래정지, 정리매매 상태가 아닌 종목을 list로 반환.
+        Args:
+            date (str; int): 날짜. int 혹은 str 타입으로 8자리. ex)20221231
+
+        Returns:
+            list : 해당 일이 휴일이라면 빈 리스트를 반환. 그렇지 않다면 거래가능한 종목코드를 반환.
+        """
+        if end is None:
+            end = start
+        trdstp = self.getTS(88, start, end).replace({1:0, 0:1})
+        liqsell = self.getTS(92, start, end).replace({1:0, 0:1})
+        tradable = (trdstp * liqsell).where(lambda x : x == 1).dropna(axis=1)
+        if tradable.shape[0]:
+            return tradable.columns.to_list()
+        else:
+            return []
 
     def _getTrailingYQ(self, yq, n=4):
         y,q = yq[:4], (yq[4:])
